@@ -12,8 +12,8 @@ var MazeModel = widgets.DOMWidgetModel.extend({
 		_view_name: "MazeView",
 		_model_module: "ttgtcanvas",
 		_view_module: "ttgtcanvas",
-		_model_module_version: "0.2.8",
-		_view_module_version: "0.2.8",
+		_model_module_version: "0.3.1",
+		_view_module_version: "0.3.1",
 		current_call: "{}",
 		method_return: "{}",
 	}),
@@ -178,6 +178,7 @@ class Robot {
 			new Konva.Image.fromURL(src, function (darthNode) {
 				that.src = src;
 				that.set_node(darthNode);
+
 				darthNode.setAttrs({
 					x: 100,
 					y: 100,
@@ -540,6 +541,10 @@ var MazeView = widgets.DOMWidgetView.extend({
 			opacity: 1,
 			easing: Konva.Easings["EaseOut"],
 			duration: 5,
+			onFinish: () =>
+				setTimeout(() => {
+					this.delete_msg();
+				}, 1000),
 		});
 		tween.play();
 	},
