@@ -15,6 +15,7 @@ def pause(delay = 1.0):
 
 _directions = [ (0, 1), (-1, 0), (0, -1), (1, 0) ]
 _orient_dict = { 'E': 3, 'S': 2, 'W': 1, 'N': 0}
+_to_rotate = { 'E': 0, 'S': 3, 'W': 2, 'N': 1}
 
 
 class _Beeper(object):
@@ -27,7 +28,7 @@ class _Beeper(object):
 
     def set_number(self, num):
         self.num = num
-        self.world.set_number(self)
+        # self.world.update_beeper(self)
 
 
 class Robot(object):
@@ -203,10 +204,10 @@ def load_world(filename):
         w = Maze(
                 avenues= wd["avenues"], 
                 walls= wd["walls"], 
-                beepers= wd["beepers"], 
+                beepers= wd.get("beepers", {}), 
                 streets= wd["streets"],
                 robot=wd["robot"],
-                flags=wd["flags"])
+                flags=wd.get("flags", []))
         return w
     except:
         raise ValueError("Error interpreting world file.")
@@ -224,9 +225,9 @@ class Maze(widgets.DOMWidget):
     # Name of the front-end module containing widget model
     _model_module = Unicode('ttgtcanvas').tag(sync=True)
 
-    _view_module_version = Unicode('^0.2.8').tag(sync=True)
+    _view_module_version = Unicode('^0.3.1').tag(sync=True)
     # Version of the front-end module containing widget model
-    _model_module_version = Unicode('^0.2.8').tag(sync=True)
+    _model_module_version = Unicode('^0.3.1').tag(sync=True)
 
     current_call  = Unicode('{}').tag(sync=True)
     method_return = Unicode('{}').tag(sync=True)
@@ -348,11 +349,15 @@ class Maze(widgets.DOMWidget):
     ##init robot
     def init_robot(self, src):
         avenue, street, orientation, beepers = self.robot
-        self.js_call('add_robot', [0, src, avenue, street,orientation, beepers])
+        self.js_call('add_robot', [0, src, avenue, street,'E', beepers])
         self._bot  =  self._bot or Robot()
-        self._bot.init(self, avenue, street, orientation, beepers, 0)
+        self._bot.init(self, avenue, street, 'E', beepers, 0)
         self.js_call('init_robot', [0])
         self._bot._update_pos()
+
+        if _to_rotate[orientation] > 0 :
+            for x in range(_to_rotate[orientation]):
+                self._bot.turn_left()
         return self._bot
 
     def bot(self):
@@ -368,7 +373,7 @@ class Maze(widgets.DOMWidget):
         self.js_call('set_trace', [rindex, x, y, color])
     
     def set_number(self, beeper):
-        self.js_call('set_beeper_number', [beeper.av, beeper.st, beeper.number])
+        self.js_call('set_beeper_number', [beeper.av, beeper.st, beeper.num])
 
     def rotate_left(self, rindex):
         self.js_call('rotate_left', [rindex])
